@@ -163,6 +163,9 @@ pub struct Hasher {
     vm: *mut randomx_vm,
 }
 
+unsafe impl Send for Hasher {}
+unsafe impl Sync for Hasher {}
+
 impl Hasher {
     pub fn new(context: Arc<Context>) -> Self {
         unsafe {
